bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 13. Aventiure
___________________________________________________
| ### Alle ir vnmvze di laze wir nv sin ### vnde sagen wi vrowe Criemhilt vnt ovch ir magedin ### gegen Rine fvren von Nibelvnge lant ### ni getrvgen moere so manich riche gewant ### Vil der sovmschrine man schiet zv den wægen ### do reit mit sinen vrivnden Sifrit der dægen ### vnd ovch div chvneginne dar si hæten vrevden wan ### sit wart ez in allen ce grozem leide getan
###### 777 | ### Da heime si do liezen Sifrides chindelin ### vnt svn Criemhilde daz mvs et also sin ### von ir hovereise im erstvnt michel ser ### sin vater vnt sin mvter gesach daz chindel nimmer mer
| ### Do reit ovch mit in dannen der herre Sigemunt ### sold er rehte wizzen wi ez nach der stvnt ### cer hogecite ergienge er hete ir niht gesehen ### im chvnde ce lieben vrivnden nimmer leider geschehen
###### 779 | ### Di boten man fvr sande di div mære sageten dar ### do reit ovch in engegen mit wnnechlicher shar ### vil der <Voten> vrivnde vnt der Gvntheres man ### der wirt gegen sinen gesten vil sere sich vlizen began
###### 780 | ### Er gie zv Prvnnhilt da er <di> sitzen vant ### wi enpfie et ivch min swester do ir chomet in min lant ### alsam sult ir enpfahen daz Sifrides wip ### daz tvn ich von schvlden gerne holt ist ir min lip
| ### Do sprach der kvenich riche si chvment morgen vrv ### welt ir si enpfahen da griffet balde zv ### daz wir in der bverge niht erbiten hie ### mir chomen in <allen> wilen so rehte liebe geste nie
###### 782 | ### Ir mægede vnt ir vrowen hiez do sa cehant ### <svchen> gvtev chleider di besten di man vant ### di ir ingesinde vor gesten solden tragen ### daz taten si doch gerne daz mach man lihte gesagen
###### 783 | ### Ovch ilten in do dienen di Gvntheres man ### alle sine rechen der wirt zv sich gewan ### do reit div kveneginne vil herliche dan ### da wart vil michel grvezen die liebe geste getan
| ### Mit wi getanen vrevden man di geste enpfie ### si dvhte daz vrov Crie [326b] mhilt vrovn Prvnnhilde nie ### so rehte wol enpfienge in Bvergvnde lant ### di si ê niht gesahen den wart vil hoher mvot erchant
###### 785 | ### Nv was ovch chomen Sifrit mit den sinen man ### man sach di helde wenden wider vnde dan ### des veldes allenthalben mit vngefvegen scharn ### dringen vnd stovben chvnde da niemen bewarn
###### 786 | ### Do der wirt des landes Sifride sach ### vnt ovch Sigemvnde wi minnechlich er do sprach ### nv sit mir groze willechomen vnt al di vrivnde min ### der iwer hovereise svl wir hohgemvte sin
| ### Nv lon iv got sprach Sigemvnt der ere gernde man ### sit daz ivch min svn Sifrit ce vrivnde gewan ### do rieten mine sinne daz ich ivch solde sæhen ### do sprach der chvnich Gvnther mir ist liebe dar an geschehen
###### 788 | ### Sifrit wart enpfangen als im <da> wol gezam ### mit vil grozen eren was im da niemen gram ### des half mit grozen zvehten Giselher vnt Gernot ### ich wæne man ez gesten noch nie so gvetlich erbot
###### 789 | ### Do nahten zv ein ander der zweir kvenege wip ### da wart vil satel lære manich schoener vrowen lip ### wart von helde handen erhaben vf daz gras ### di vrowen gerne dienten waz der vmmvezegen was
| ### Do giengen zv ein ander div minnechlichen wip ### des was in grozen vrevden vil maniges ritters lip ### daz ir beider grvezen so schone wart getan ### do sach man vil der rechen bi ir ivnchvrowen stan
###### 791 | ### Daz herliche gesinde daz vie sich bi der hant ### in zvehte groze nigen des man vil da vant ### vnd chvessen minnechlichen von vrowen wolgetan ### daz was liep ce sæhene Gvnthers vnd Sifrides man
###### 792 | ### Sine bitten da niht langer si ritten zv der stat ### der wirt daz sinen gesten wol er ceigen bat ### daz man si gerne sæhe in Bvrgvnden lant ### vil manigen pvneiz richen man vor den ivnchvrowen vant
| ### Vzer Tronege Hagene vnt ovch Ortwin ### da si gewaldech wæren daz taten si wol schin ### swaz si gebieten wolden daz torste man niht lan ### von in wart [327a] michel dienest den lieben gesten getan
###### 794 | ### Vil schilde hort man hellen da ce dem pvergetor ### von stichen vnd von stoezen lange habt der vor ### der wirt mit sinen gesten ê si chomen drin ### ia giench in div stvnde mit grozer chverzwile hin
###### 795 | ### Fver den palas richen mit vrowen si do ritten ### manegen pfellel spæhen gvt vnd wol gesniten ### sach man vber sætel den vrowen wolgetan ### allenthalben hangen do chomen Gvntheres man
###### 796 | ### <Di> geste hiez man fveren balde an ir gemach ### vnder <wilen> blicken man Prvnnhilde sach ### <an> vrovn Criemhilde div schoene was genvch ### ir varwe gegen dem golde den glanz vil herlichen trvch
###### 797 | ### Allenthalben schallen ce Wormez in der stat ### horte manz gesinde Gvnther do bat ### Danchwarten sinen marshalch daz ir solde pflegen ### do begond er daz gesinde harte gvetliche legen
###### 798 | ### Dar vze vnt ovch dar inne spisen man si lie ### ia <wart> vremder geste baz gepflegen nie ### alles des si gerten des was man in bereit ### der chvenech der was so riche daz da niemen niht wart verseit
| ### Man diente vrivntliche vnd an allen haz ### der wirt do ce tissche mit sinen gesten saz ### man bat Sifride sitzen als er het ê getan ### do gi mit im ce sedele vil manich wætlicher man
###### 800 | ### Wol zwelf hvndert recken an dem ringe sin ### da ce tissche sazen Prvnnhilt div chvnegin ### gedaht daz eigenholde niht richer chvnde wesin ### si was im noch so wæge daz si in gerne lie genæsin
###### 801 | ### An einem abende da der chvenech saz ### vil der richen chleider wart von wine naz ### da si schenchen solden zv den tisschen gan ### da wart vil voller dienest mit grozem vlize getan
| ### So man ce hohziten lange hat gepflegen ### vrowen vnt mægde dihiez man schone legen ### von swannen si dar chomen der wirt in willen trvch ### mit gvtlichen eren man gap in allen genvch
###### 803 | ### Do div naht het ende vnt der tach ershein ### vz den sovmshrinen vil manich edel stein ### erlvht in gvter wæte di rvorte vrowen hant ### do wart dar fver gesvchet vil manich herlich gewant
###### 804 | ### ê daz wol ertagete do chomen fver den sal ### vil ritter vnde chnehte do hvp sich aber der shal ### vor einer vrvemesse di man dem [327b] chvenige sanch ### da ritten ivnge helde daz sin der chvenech sagete danch
| ### Vil crepfteliche lvte manich pvsv^n erdoz ### von trvmben vnt von floyten wart der shal so groz ### daz Wormez div vil wite dar nach lvt ershal ### di hohgemvten helde ce rossen chomen veberal
###### 806 | ### Do hvp sich in dem lande vil harte hohe ein spil ### von manigem gvtem rechen der sah man da vil ### den ir tvmbiv herce gaben hohen mvt ### da sah man vnder shilde vil manigen cieren ritter gvt
###### 807 | ### In div venster sazen div herlichiv wip ### vnd vil der schoenen mægede gecieret was ir lip ### si sahen chverzewile von manigem chvenem man ### der wirt mit sinen vrivnden selbe riten began
| ### Svs vertriben si di wile div dvhte niht lanch ### man horte da cem tvome maniger gloken chlanch ### do chomen in di moere di vrowen ritten dan ### den edelen chveneginnen den volgete manech chvene man
###### 809 | ### Si stvnden vor dem mvenster nider vf daz gras ### Prvnnhilt ir gesten dannoch vil wæge was ### si giengen vnder crone in daz mvenster wit ### div liebe wart sit gesheiden daz frvmte grozlicher nit
###### 810 | ### Do si gehorten messe si fvren wider dan ### mit vil manigen eren man sach sider gan ### ce tissche vroliche ir vrevde nie gelach ### da cer hohgecite vnz an den einlefften tach

<<< Übersicht <<< vorige Seite nächste Seite >>>